<?php
/**
 * Plugin Name: Funraise Donation Form
 * Description: Use Funraise to add donation forms to your website with a shortcode. Manage donations and donors in Funraise's free platform.
 * Version:     1.0.1
 * Author:      Funraise, Inc.
 * Author URI:  https://funraise.org
 * License:     MIT License
 * License URI: https://directory.fsf.org/wiki/License:Expat
 */

function funraise_validate_url($url) {
    $giving_page_url_regex = '/\/give\/[^\/]+\//i';
    $valid_url_regex = '/^(http:\/\/www\.|https:\/\/www\.|http:\/\/|https:\/\/)[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,5}(:[0-9]{1,5})?(\/.*)?(\/\S*)?$/';

    return (
        (preg_match($giving_page_url_regex, $url) === 1) &&
        (preg_match($valid_url_regex, $url) === 1) &&
        (filter_var($url, FILTER_VALIDATE_URL) !== false)
    );
}

function funraise_embed_template($form_embed_url) {
    if ($form_embed_url === '') {
        return '';
    }

    return '<div class="wp-funraise-embed-giving-form"><script src="'.$form_embed_url.'"></script></div>';
}

function funraise_embed_form($atts) {
    $atts = shortcode_atts(array(
        'form'      => '',
        'button'    => ''
    ), $atts);

    $placed_form_input = $atts['form'];
    $button_input = $atts['button'];

    $form_embed_url = '';

    if ($placed_form_input != '' && funraise_validate_url($placed_form_input) === true) {
        $form_embed_url = $placed_form_input.'/embed/placed-form.js';
    } else if ($button_input != '' && funraise_validate_url($button_input) === true) {
        $form_embed_url = $button_input.'/embed/button.js';
    }

    return funraise_embed_template($form_embed_url);
}

function funraise_render_plugin_settings_page() {
    ?>
        <?php include 'includes/settings-page.php';?>
    <?php
}

function funraise_register_settings_page() {
    add_options_page('Funraise', 'Funraise', 'manage_options', 'funraise-donation-form', 'funraise_render_plugin_settings_page');
}

function funraise_add_settings_link($links) {
    $url = get_admin_url() . 'options-general.php?page=funraise-donation-form';
    $settings_link = '<a href="' . $url . '">' . __('Settings', 'Funraise') . '</a>';
    array_unshift( $links, $settings_link );
    return $links;
}

function funraise_after_setup_theme() {
     add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'funraise_add_settings_link');
}

add_shortcode('funraise' , 'funraise_embed_form');
add_action('admin_menu', 'funraise_register_settings_page');
add_action('after_setup_theme', 'funraise_after_setup_theme');
?>